@@ -1,4 +1,4 @@
-use 5.008009;
+use 5.008001;
 use strict;
 use warnings;
 use XSLoader ();
@@ -6,7 +6,7 @@ use XSLoader ();
 package Class::XSConstructor;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006';
+our $VERSION   = '0.007';
 
 use Exporter::Tiny 1.000000 qw( mkopt );
 use Ref::Util 0.100 qw( is_plain_arrayref is_plain_hashref is_blessed_ref is_coderef );
@@ -16,7 +16,13 @@ sub import {
 	my $class  = shift;
 	my $caller = our($SETUP_FOR) || caller;
 	
-	install_constructor("$caller\::new");
+	if (our $REDEFINE) {
+		no warnings 'redefine';
+		install_constructor("$caller\::new");
+	}
+	else {
+		install_constructor("$caller\::new");
+	}
 	inheritance_stuff($caller);
 	
 	my ($HAS, $REQUIRED, $ISA, $BUILDALL) = get_vars($caller);
